==> treeland_0.7.3.tar.xz: BUILD/translations/treeland.tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>WindowMenu</name>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="29"/>
        <source>Minimize</source>
        <translation>Küçült</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="34"/>
        <source>Unmaximize</source>
        <translation>Önceki Boyut</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="34"/>
        <source>Maximize</source>
        <translation>Ekranı Kapla</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="39"/>
        <source>Move</source>
        <translation>Taşı</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="44"/>
        <source>Resize</source>
        <translation>Boyutlandır</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="50"/>
        <source>Always on Top</source>
        <translation>Sürekli Üstte</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="56"/>
        <source>Always on Visible Workspace</source>
        <translation>Sürekli Çalışma Alanında Görün</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="70"/>
        <source>Move to Left Work Space</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="77"/>
        <source>Move to Right Work Space</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="83"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
</context>
</TS>

==> treeland_0.7.8.tar.xz: BUILD/translations/treeland.tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>WindowMenu</name>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="29"/>
        <source>Minimize</source>
        <translation>Küçült</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="34"/>
        <source>Unmaximize</source>
        <translation>Önceki Boyut</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="34"/>
        <source>Maximize</source>
        <translation>Ekranı Kapla</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="39"/>
        <source>Move</source>
        <translation>Taşı</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="44"/>
        <source>Resize</source>
        <translation>Boyutlandır</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="50"/>
        <source>Always on Top</source>
        <translation>Sürekli Üstte</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="56"/>
        <source>Always on Visible Workspace</source>
        <translation>Sürekli Çalışma Alanında Görün</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="70"/>
        <source>Move to Left Work Space</source>
        <translation>Sol Çalışma Alanına Taşı</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="77"/>
        <source>Move to Right Work Space</source>
        <translation>Sağ Çalışma AlanınaTaşı</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="83"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
</context>
</TS>
